<?php

/**
 * @file
 * Views handlers for cd_sunlight.
 */

/**
 * Field handler to fetch the congress member's photo from Bioguide.
 *
 * @ingroup views_field_handlers
 */
class cd_sunlight_handler_field_congress_picture extends views_handler_field {

  function option_definition() {
    $options = parent::option_definition();
    $options['format'] = array('default' => '');
    return $options;
  }

  function options_form(&$form, &$form_state) {
    parent::options_form($form, $form_state);
    if (module_exists('imagecache')) {
      $formats = array('' => '- None -');
      foreach (imagecache_presets() as $preset) {
        $formats[$preset['presetname']] = $preset['presetname'];
      }
      $form['format'] = array(
        '#title' => t('Format'),
        '#type' => 'select',
        '#default_value' => !empty($this->options['format']),
        '#options' => $formats,
      );
    }
  }

  /**
   * Add all the fields that we need.
   */
  function construct() {
    parent::construct();
    $this->additional_fields['bioguide_id'] = 'bioguide_id';
  }

  function query() {
    $this->ensure_my_table();
    $this->add_additional_fields();
  }

  function render($values) {
    if (empty($values->{$this->aliases['bioguide_id']})) {
      return '';
    }

    $image_url = cd_sunlight_bioguide_image_url($values->{$this->aliases['bioguide_id']});
    $attributes = array();
    $alt = $title = '';
    if ($values->cd_sunlight_legislators_lastname) {
      $title = "$values->cd_sunlight_legislators_title. $values->cd_sunlight_legislators_firstname $values->cd_sunlight_legislators_lastname";
      $alt = "Photo of $title";
    }
    // If the image style is resizing the image, add the dimensions to the img tag.
    // This is a front-end performance improvement.  But it will also prevent
    // layout issues if Bioguide is being slow and thus we get images directly
    // from them and not the cache.
    if (!empty($this->options['format']) && function_exists('theme_imagecache')) {
      $preset = imagecache_preset($this->options['format']);
      foreach ($preset['actions'] as $action) {
        foreach (array('width', 'height') as $dimension) {
          if (!empty($action['data'][$dimension]) && strpos($action['data'][$dimension], '%') === FALSE) {
            $attributes[$dimension] = $action['data'][$dimension];
          }
        }
      }
    }
    if (!empty($this->options['format']) && strpos($image_url, 'http') !== 0) {
      return theme('imagecache', $this->options['format'], $image_url, $alt, $title, $attributes, FALSE);
    }
    else {
      return theme('image', $image_url, $alt, $title, $attributes, FALSE);
    }
  }

}
